==> pyeccodes-0.0.6.tar.gz: pyeccodes-0.0.6/pyeccodes/defs/grib1/localConcepts/ecmf/stepType_def.py <==
import pyeccodes.accessors as _


def load(h):

    def wrapped(h):

        timeRangeIndicator = h.get('timeRangeIndicator')

        if timeRangeIndicator == 0:
            return 'instant'

        if timeRangeIndicator == 10:
            return 'instant'

        if timeRangeIndicator == 1:
            return 'instant'

        if timeRangeIndicator == 14:
            return 'instant'

        if timeRangeIndicator == 3:
            return 'avg'

        if timeRangeIndicator == 113:
            return 'avgd'

        if timeRangeIndicator == 113:
            return 'avgfc'

        if timeRangeIndicator == 4:
            return 'accum'

        if timeRangeIndicator == 2:
            return 'accum'

        centre = h.get('centre')

        if timeRangeIndicator == 2 and centre == 98:
            return 'min'

        if timeRangeIndicator == 119:
            return 'min'

        if timeRangeIndicator == 2 and centre == 98:
            return 'max'

        if timeRangeIndicator == 118:
            return 'max'

        if timeRangeIndicator == 5:
            return 'diff'

        if timeRangeIndicator == 120:
            return 'rms'

        if timeRangeIndicator == 121:
            return 'sd'

        if timeRangeIndicator == 122:
            return 'cov'

        if timeRangeIndicator == 123:
            return 'avgua'

        if timeRangeIndicator == 124:
            return 'avgia'

        if timeRangeIndicator == 128:
            return 'avgas'

        if timeRangeIndicator == 130:
            return 'avgad'

        if timeRangeIndicator == 133:
            return 'avgid'

    return wrapped

==> pyeccodes-0.1.1.tar.gz: pyeccodes-0.1.1/pyeccodes/defs/grib1/localConcepts/ecmf/stepType_def.py <==
import pyeccodes.accessors as _


def load(h):

    def wrapped(h):

        timeRangeIndicator = h.get_l('timeRangeIndicator')

        if timeRangeIndicator == 133:
            return 'avgid'

        if timeRangeIndicator == 130:
            return 'avgad'

        if timeRangeIndicator == 128:
            return 'avgas'

        if timeRangeIndicator == 124:
            return 'avgia'

        if timeRangeIndicator == 123:
            return 'avgua'

        if timeRangeIndicator == 122:
            return 'cov'

        if timeRangeIndicator == 121:
            return 'sd'

        if timeRangeIndicator == 120:
            return 'rms'

        if timeRangeIndicator == 5:
            return 'diff'

        if timeRangeIndicator == 118:
            return 'max'

        centre = h.get_l('centre')

        if timeRangeIndicator == 2 and centre == 98:
            return 'max'

        if timeRangeIndicator == 119:
            return 'min'

        if timeRangeIndicator == 2 and centre == 98:
            return 'min'

        if timeRangeIndicator == 2:
            return 'accum'

        if timeRangeIndicator == 4:
            return 'accum'

        if timeRangeIndicator == 113:
            return 'avgfc'

        if timeRangeIndicator == 113:
            return 'avgd'

        if timeRangeIndicator == 3:
            return 'avg'

        if timeRangeIndicator == 14:
            return 'instant'

        if timeRangeIndicator == 1:
            return 'instant'

        if timeRangeIndicator == 10:
            return 'instant'

        if timeRangeIndicator == 0:
            return 'instant'

    return wrapped
